calview.DailyPlannerRow (Planner row) — amici1

# `calview.DailyPlannerRow` (Planner row)

DailyPlannerRow(id, seqno, designation, start_time, end_time, designation_de, designation_fr)

Master tables : calview.DailyPlannerRows (Planner rows)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- No. (seqno) : The sequence number of this item with its parent.

- Designation (designation) : See `<lino.utils.mldbc.fields.BabelCharField: designation>`.

- Start time (start_time) : See `<lino.core.fields.TimeField: start_time>`.

- End time (end_time) : See `<lino.core.fields.TimeField: end_time>`.

- Designation (de) (designation_de) : See `<django.db.models.fields.CharField: designation_de>`.

- Designation (fr) (designation_fr) : See `<django.db.models.fields.CharField: designation_fr>`.

- Name (name_column) : See `lino_xl.lib.calview.models.DailyPlannerRow.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.calview.models.DailyPlannerRow.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- Time range (overview) : See `lino_xl.lib.calview.models.DailyPlannerRow.overview`.

- Move (move_buttons) : Displays buttons for certain actions on this row:

- Time range (overview) : See `lino_xl.lib.calview.models.DailyPlannerRow.overview`.

Referenced from

## Database fields

Internal name | Verbose name | Help text
id | ID |
seqno | No. | The sequence number of this item with its parent.
designation | Designation |
start_time | Start time |
end_time | End time |
designation_de | Designation (de) |
designation_fr | Designation (fr) |
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | Time range |
move_buttons | Move | Displays buttons for certain actions on this row:
overview | Time range |